<?xml version="1.0" encoding="ISO-8859-1"?>

<!-- Stylesheet to generate intermediate XML files which are later processed by site.xsl -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
  xmlns:redirect="http://xml.apache.org/xalan/redirect"
  extension-element-prefixes="redirect">

<!--
	N.B. any tags with more than one attribute need to be coded using xsl:attribute 
	for all but the first attribute.
	This is to ensure that JDK 1.4 and 1.5 generate the attributes in the same order.	
-->
<!--
	Warning: 
	There seems to be a bug in JDK 1.5.0_02 - if you try to use indent="yes" with redirect:write,
	some files can be mangled at the start of the output.
-->
  <!-- Defined parameters (overrideable) -->
  <xsl:param    name="docs.downloads.tmp" select="'target/download-xdocs'"/>

  <!-- Defined variables (non-overrideable) -->


  <xsl:template match="project">
    <xsl:variable name="id"><xsl:value-of select="@id"/></xsl:variable>
    <redirect:write file="{$docs.downloads.tmp}/downloads_{$id}.xml">
      <document>
      <properties>
        <title><xsl:value-of select="@name"/> Downloads</title>
      </properties>
      <body>
        <xsl:variable name="href"><xsl:value-of select="@href"/></xsl:variable>
        <xsl:variable name="name"><xsl:value-of select="@name"/></xsl:variable>
        <section name="{$name} Downloads">

        <xsl:if test="downloads">
        <xsl:if test="downloads/@mirrored != 'false'">
            <p>We recommend you use a mirror to download our release
            builds, but you <strong>must</strong> verify the integrity of
            the downloaded files using signatures downloaded from our main 
            distribution directories. Recent releases (48 hours) may not yet be available from the mirrors. </p>

            <p>You are currently using <b>[preferred]</b>.  If you
            encounter a problem with this mirror, please select another
            mirror.  If all mirrors are failing, there are <i>backup</i>
            mirrors (at the end of the mirrors list) that should be
            available.<br/>[if-any logo]<a href="[link]"><img align="right">
            <xsl:attribute name="src"><xsl:value-of select="'[logo]'"/></xsl:attribute>
            <xsl:attribute name="border"><xsl:value-of select="'0'"/></xsl:attribute>
            </img></a>[end]</p>

            <p>
            <form action="[location]">
            <xsl:attribute name="method"><xsl:value-of select="'get'"/></xsl:attribute>
            <xsl:attribute name="id"><xsl:value-of select="'SelectMirror'"/></xsl:attribute>
              Other mirrors: <select name="Preferred">
              [if-any http]
                [for http]<option value="[http]">[http]</option>[end]
              [end]
              [if-any ftp]
                [for ftp]<option value="[ftp]">[ftp]</option>[end]
              [end]
              [if-any backup]
                [for backup]<option value="[backup]">[backup] (backup)</option>[end]
              [end]
              </select>
              <input type="submit">
              <xsl:attribute name="value"><xsl:value-of select="'Change'"/></xsl:attribute>
              </input>
            </form>
            </p>
        </xsl:if>
        <p>

        <!-- TODO: See the md5 TODO below, this is the same but for pgp -->
        <xsl:if test="not(downloads/@pgp-text and downloads/@pgp-text = 'false')">
            The <code>KEYS</code> link links to the code signing keys used to sign the product. The <code>PGP</code> link downloads the OpenPGP compatible signature from our main site. 
        </xsl:if>

        <!-- TODO: Only show this if there are MD5 links in the download, rather than the downloads -->
        <!--       Basically need to not show this if all the download/*/@md5 are present and false -->
        <xsl:if test="not(downloads/@md5-text and downloads/@md5-text = 'false')">
            The <code>MD5</code> link downloads the checksum from the main site.
        </xsl:if>
        </p>
        </xsl:if>

        <xsl:if test="@name and @href">
            <p>For more information concerning <xsl:value-of select="@name"/>, see the <a href="{$href}">
            <xsl:attribute name="class"><xsl:value-of select="'name'"/></xsl:attribute>
            <xsl:value-of select="@name"/></a> site. </p>
        </xsl:if>

          <xsl:if test="project">
            <ul>
              <xsl:for-each select="project">
                <xsl:call-template name="subproject"/>
              </xsl:for-each>
            </ul>
          </xsl:if>
          <xsl:apply-templates select="downloads"/>
        </section>
      </body>
      </document>
    </redirect:write>
  </xsl:template>

  <!-- used to match nested project tags -->
  <!-- largely matches the project template in download-page.xsl -->
  <xsl:template name="subproject">
    <xsl:variable name="id"><xsl:value-of select="@id"/></xsl:variable>
    <xsl:if test="downloads">
      <xsl:if test="downloads/@mirrored != 'false'">
        <li class="project">
          <a href="downloads_{$id}.cgi"><xsl:value-of select="@name"/></a>
        </li>
      </xsl:if>
      <xsl:if test="downloads/@mirrored = 'false'">
        <li class="unmirrored_project">
          <a href="downloads_{$id}.html"><xsl:value-of select="@name"/></a>
        </li>
      </xsl:if>
    </xsl:if>
    <xsl:if test="not(downloads)">
      <li class="tiered_project">
        <a href="downloads_{$id}.html"><xsl:value-of select="@name"/></a>
      </li>
    </xsl:if>

    <redirect:write file="{$docs.downloads.tmp}/downloads_{$id}.xml">
        <xsl:apply-templates select="."/>
    </redirect:write>
  </xsl:template>

  <xsl:template match="downloads">
    <xsl:variable name="keys"><xsl:value-of select="@keys"/></xsl:variable>
    <xsl:variable name="primary"><xsl:value-of select="@primary"/></xsl:variable>
    <xsl:variable name="mirrored"><xsl:value-of select="@mirrored"/></xsl:variable>
    <xsl:variable name="archive"><xsl:value-of select="@archive"/></xsl:variable>
    <div class="links">
      <xsl:if test="@keys">
        <span class="link"><a href="{$primary}{$keys}">KEYS</a></span>
      </xsl:if>
      <xsl:apply-templates select="link">
        <xsl:with-param name="primary" select="@primary"/>
      </xsl:apply-templates>
    </div>
    <ul class="downloads">
      <xsl:apply-templates select="group">
        <xsl:with-param name="primary" select="@primary"/>
      </xsl:apply-templates>
      <xsl:apply-templates select="download">
        <xsl:with-param name="primary" select="@primary"/>
      </xsl:apply-templates>
      <xsl:if test="@archive">
        <li><a href="{$archive}">archives...</a></li>
      </xsl:if>
    </ul>
  </xsl:template>

  <xsl:template match="group">
    <xsl:param name="primary"/>
    <li class="group">
      <div class="links">
        <span class="label"><xsl:value-of select="@label"/></span>
        <xsl:apply-templates select="link">
          <xsl:with-param name="primary" select="$primary"/>
        </xsl:apply-templates>
      </div>
      <ul>
      <xsl:apply-templates select="group">
        <xsl:with-param name="primary" select="$primary"/>
      </xsl:apply-templates>
      <xsl:apply-templates select="download">
        <xsl:with-param name="primary" select="$primary"/>
      </xsl:apply-templates>
      </ul>
    </li>
  </xsl:template>

  <xsl:template match="link">
    <xsl:param name="primary"/>
    <xsl:variable name="href"><xsl:value-of select="@href"/></xsl:variable>
    <span class="link"><a href="{$href}"><xsl:value-of select="@name"/></a></span>
  </xsl:template>

  <xsl:template match="download">
    <xsl:param name="primary"/>
    <xsl:variable name="href"><xsl:value-of select="@href"/></xsl:variable>
<!-- TODO: If name doesn't exist, then use the last part of the href -->
    <li class="download">
      <xsl:if test="ancestor::downloads/@mirrored = 'true'">
          <a href="[preferred]/{$href}"><xsl:value-of select="@name"/></a> 
      </xsl:if>
      <xsl:if test="not(ancestor::downloads/@mirrored = 'true')">
          <a href="{$primary}{$href}"><xsl:value-of select="@name"/></a> 
      </xsl:if>
      <xsl:if test="not(@directory = 'true') and not(@md5 and @md5 = 'false' and @pgp and @pgp = 'false')">
          <ul class="attributes"><li>
          <xsl:if test="not(@md5 and @md5 = 'false')">
            <span class="md5">[<a href="{$primary}{$href}.md5">md5</a>]</span>
          </xsl:if>
          <xsl:if test="not(@pgp and @pgp = 'false')">
            <span class="pgp">[<a href="{$primary}{$href}.asc">pgp</a>]</span>
          </xsl:if>
          </li></ul>
      </xsl:if>
    </li>
  </xsl:template>

</xsl:stylesheet>
